@@ -9,7 +9,7 @@ use Child::Link::Parent;
 
 use Exporter 'import';
 
-our $VERSION = "0.010";
+our $VERSION = "0.012";
 our @PROCS;
 our @EXPORT_OK = qw/child/;
 
@@ -23,6 +23,14 @@ sub child(&;@) {
 
 sub all_procs { @PROCS }
 
+sub _clean_proc {
+    my $class = shift;
+    my ($proc) = @_;
+    return unless $proc;
+    return unless @PROCS;
+    @PROCS = grep { $_ && $proc != $_ } @PROCS;
+}
+
 sub all_proc_pids {
     my $class = shift;
     map { $_->pid } $class->all_procs;
